----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: scalp_matrix_index.vhd
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.1
-- Description: Determines the index of the output vector.
--
-- Last update: 2020-01-19
--
---------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

--use ieee.std_logic_unsigned.all;
--use ieee.std_logic_arith.all;
--use ieee.std_logic_misc.all;

--library UNISIM;
--use UNISIM.VCOMPONENTS.all;

entity scalp_matrix_index is

    generic (
        C_SCALP_INTERFACE_VECTOR_SIZE : integer range 0 to 255 := 7);

    port (
        IfSrcNumxDI      : in  integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1);
        IfDstNumxDI      : in  integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1);
        IfNumValidxSI    : in  std_ulogic;
        IfDstIdxxDO      : out integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1);
        IfDstIdxValidxSO : out std_ulogic);

end entity scalp_matrix_index;

architecture behavioral of scalp_matrix_index is

    signal IfNumValidxS    : std_ulogic                                             := '0';
    signal IfDstIdxValidxS : std_ulogic                                             := '0';
    signal IfSrcNumxD      : integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) := 0;
    signal IfDstNumxD      : integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) := 0;
    signal IfDstIdxxD      : integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) := 0;

begin  -- architecture behavioral

    EntityIOxB : block is
    begin  -- block EntityIOxB

        IfSrcNumxAS      : IfSrcNumxD       <= IfSrcNumxDI;
        IfDstNumxAS      : IfDstNumxD       <= IfDstNumxDI;
        IfNumValidxAS    : IfNumValidxS     <= IfNumValidxSI;
        IfDstIdxxAS      : IfDstIdxxDO      <= IfDstIdxxD;
        IfDstIdxValidxAS : IfDstIdxValidxSO <= IfDstIdxValidxS;

    end block EntityIOxB;

    MatrixIndexxP : process (IfDstNumxD, IfNumValidxS, IfSrcNumxD) is
    begin  -- process MatrixIndexxP
        IfDstIdxxD      <= 0;
        IfDstIdxValidxS <= '0';

        if (IfSrcNumxD < IfDstNumxD) and (IfNumValidxS = '1') then
            IfDstIdxxD      <= IfDstNumxD - (IfSrcNumxD + 1);
            IfDstIdxValidxS <= '1';
        elsif (IfSrcNumxD > IfDstNumxD) and (IfNumValidxS = '1') then
            IfDstIdxxD      <= ((C_SCALP_INTERFACE_VECTOR_SIZE - 1) - IfSrcNumxD) + IfDstNumxD;
            IfDstIdxValidxS <= '1';
        end if;
    end process MatrixIndexxP;

end architecture behavioral;
