----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: tb_scalp_tx_side.vhd
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.1
-- Description: Testbench for scalp_tx_side.
--
-- Last update: 2020-02-12
--
---------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use ieee.math_real.all;
-- use ieee.math_real.uniform;
-- use ieee.math_real.floor;

--use ieee.std_logic_unsigned.all;
--use ieee.std_logic_arith.all;
--use ieee.std_logic_misc.all;

--library UNISIM;
--use UNISIM.VCOMPONENTS.all;

library work;
use work.aurora_axi4_pkg.all;
use work.scalp_misc.all;
use work.scalp_utility.all;

entity tb_scalp_tx_side is

end entity tb_scalp_tx_side;

architecture testbench of tb_scalp_tx_side is

    constant C_CLK_PERIOD                      : time                                                 := 10 ns;
    -- scalp_tx_side
    constant C_SCALP_INTERFACE_VECTOR_SIZE     : integer range 0 to 255                               := 7;
    constant C_SCALP_NEIGHBORS_VECTOR_SIZE     : integer range 0 to 255                               := 6;
    constant C_SCALP_SCHEDULER_ACK_VECTOR_SIZE : integer range 0 to 255                               := 1;
    constant C_SCALP_LOCAL_IF_ID               : integer range 0 to 255                               := C_NORTH_IF_ID;
    -- scalp_sp_to_axis
    constant C_SCALP_PACKET_PAYLOAD_SIZE       : integer range 1 to C_SCALP_PACKET_LENGTH_RANGE_VALUE := 8;
    constant C_SCALP_RANDOM_READY              : boolean                                              := false;
    constant C_SCALP_DELAY_SIZE                : integer range 0 to 255                               := 10;

    -- Scalp Packet Headers
    constant C_SP_HEADER_0 : t_scalp_packet_header
        := (DstAddrxD =>
            (XxD     => 1,
             YxD     => 2,
             ZxD     => 3),
            SrcAddrxD =>
            (XxD     => 4,
             YxD     => 5,
             ZxD     => 6),
            TypexD   => 1,
            LengthxD => C_SCALP_PACKET_PAYLOAD_SIZE);
    -- Scalp Packet Payloads
    constant C_SP_PAYLOAD_0 : t_scalp_packet_payload(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))
        := (0 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0abbccdd#, (C_BYTE_SIZE * 4))),
             IdxD   => 0),
            1 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0bccddee#, (C_BYTE_SIZE * 4))),
             IdxD   => 1),
            2 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0cddeeff#, (C_BYTE_SIZE * 4))),
             IdxD   => 2),
            3 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0deeff11#, (C_BYTE_SIZE * 4))),
             IdxD   => 3),
            4 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0eff1122#, (C_BYTE_SIZE * 4))),
             IdxD   => 4),
            5 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#0f112233#, (C_BYTE_SIZE * 4))),
             IdxD   => 5),
            6 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#01223344#, (C_BYTE_SIZE * 4))),
             IdxD   => 6),
            7 =>
            (WordxD => std_ulogic_vector(to_unsigned(16#02334455#, (C_BYTE_SIZE * 4))),
             IdxD   => 7));

    component scalp_sp_to_axis is
        generic (
            C_SCALP_PACKET_PAYLOAD_SIZE : integer range 1 to C_SCALP_PACKET_LENGTH_RANGE_VALUE);
        port (
            SysClkxCI           : in  std_ulogic;
            SysRstxRNAI         : in  std_ulogic;
            ScalpPacketxDI      : in  t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1)));
            ScalpPacketValidxSI : in  std_ulogic;
            ScalpAxism2sxDO     : out t_axi4m2s;
            ScalpAxiss2mxDI     : in  t_axi4s2m);
    end component scalp_sp_to_axis;

    component scalp_axis_to_sp is
        generic (
            C_SCALP_PACKET_PAYLOAD_SIZE : integer range 1 to C_SCALP_PACKET_LENGTH_RANGE_VALUE;
            C_SCALP_RANDOM_READY        : boolean);
        port (
            SysClkxCI           : in  std_ulogic;
            SysRstxRNAI         : in  std_ulogic;
            ScalpAxism2sxDI     : in  t_axi4m2s;
            ScalpAxiss2mxDO     : out t_axi4s2m;
            ScalpPacketxDO      : out t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1)));
            ScalpPacketValidxSO : out std_ulogic);
    end component scalp_axis_to_sp;

    component scalp_tx_side is
        generic (
            C_SCALP_SCHEDULER_ACK_VECTOR_SIZE : integer range 0 to 255);
        port (
            SysClkxCI             : in  std_ulogic;
            SysRstxRNAI           : in  std_ulogic;
            DstRouterNetAddrxDO   : out t_scalp_netaddr;
            RouterNetAddrValidxSO : out std_ulogic;
            BookingVectorValidxSI : in  std_ulogic;
            -- SchedulerAckxDI       : in  std_ulogic_vector((C_SCALP_SCHEDULER_ACK_VECTOR_SIZE - 1) downto 0);
            RXAxi4M2SLinkxDI      : in  t_axi4m2s;
            RXAxi4S2MLinkxDO      : out t_axi4s2m;
            TXAxi4M2SLinkxDO      : out t_axi4m2s;
            TXAxi4S2MLinkxDI      : in  t_axi4s2m);
    end component scalp_tx_side;

    -- Sys Clk and Sys nRst
    signal SysClkxC             : std_ulogic      := '0';
    signal SysRstxRNA           : std_ulogic      := '0';
    -- End of Simulation
    signal EndSimxS             : boolean         := false;
    -- scalp_tx_side
    signal DstRouterNetAddrxD   : t_scalp_netaddr := C_3D_MIN_SCALP_NETADDR;
    signal RouterNetAddrValidxS : std_ulogic      := '0';
    signal BookingVectorValidxS : std_ulogic      := '0';
    -- signal SchedulerAckxD       : std_ulogic_vector((C_SCALP_SCHEDULER_ACK_VECTOR_SIZE - 1) downto 0) := (others => '0');
    signal RXAxi4M2SLinkxD      : t_axi4m2s       := C_NO_AXI4_M2S;
    signal RXAxi4S2MLinkxD      : t_axi4s2m       := C_NO_AXI4_S2M;
    signal TXAxi4M2SLinkxD      : t_axi4m2s       := C_NO_AXI4_M2S;
    signal TXAxi4S2MLinkxD      : t_axi4s2m       := C_NO_AXI4_S2M;
    -- scalp_sp_to_axis
    signal ScalpPacketValidxS   : std_ulogic      := '0';
    signal ScalpPacketxD        : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_0,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValidEndxS : std_ulogic := '0';
    signal ScalpPacketEndxD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));

begin  -- architecture testbench

    ScalpSpToAxisxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketxD,
            ScalpPacketValidxSI => ScalpPacketValidxS,
            ScalpAxism2sxDO     => RXAxi4M2SLinkxD,
            ScalpAxiss2mxDI     => RXAxi4S2MLinkxD);

    ScalpTXSidexI : entity work.scalp_tx_side
        generic map (
            C_SCALP_SCHEDULER_ACK_VECTOR_SIZE => C_SCALP_SCHEDULER_ACK_VECTOR_SIZE)
        port map (
            SysClkxCI             => SysClkxC,
            SysRstxRNAI           => SysRstxRNA,
            DstRouterNetAddrxDO   => DstRouterNetAddrxD,
            RouterNetAddrValidxSO => RouterNetAddrValidxS,
            BookingVectorValidxSI => BookingVectorValidxS,
            -- SchedulerAckxDI       => SchedulerAckxD,
            RXAxi4M2SLinkxDI      => RXAxi4M2SLinkxD,
            RXAxi4S2MLinkxDO      => RXAxi4S2MLinkxD,
            TXAxi4M2SLinkxDO      => TXAxi4M2SLinkxD,
            TXAxi4S2MLinkxDI      => TXAxi4S2MLinkxD);

    ScalpAxisToSpxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxi4M2SLinkxD,
            ScalpAxiss2mxDO     => TXAxi4S2MLinkxD,
            ScalpPacketxDO      => ScalpPacketEndxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxS);

    AsyncStatementsxB : block is
    begin  -- block AsyncStatementsxB

        SysClkxAS : SysClkxC   <= not SysClkxC after (C_CLK_PERIOD / 2);
        SysRstxAS : SysRstxRNA <= '1'          after (C_CLK_PERIOD * 10);

    end block AsyncStatementsxB;

    EndSimxP : process is
    begin  -- process EndSimxP
        if EndSimxS = true then
            assert false report "End of simulation!" severity failure;
        end if;

        wait until rising_edge(SysClkxC);
    end process EndSimxP;

    ScalpTXSideGenxP : process is
    begin  -- process ScalpTXSideGenxP

        -- TXAxi4S2MLinkxD.ReadyxS <= '1';

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        ScalpPacketValidxS <= '0';

        for i in 0 to 5 loop
            wait until rising_edge(SysClkxC);
        end loop;  -- i

        ScalpPacketValidxS <= '1';

        for i in 0 to 0 loop
            wait until rising_edge(SysClkxC);
        end loop;  -- i

        ScalpPacketValidxS <= '0';

        for i in 0 to 5 loop
            wait until rising_edge(SysClkxC);
        end loop;  -- i

        BookingVectorValidxS <= '1';

        for i in 0 to 0 loop
            wait until rising_edge(SysClkxC);
        end loop;  -- i

        BookingVectorValidxS <= '0';

        -- for i in 0 to 3 loop
        --     wait until rising_edge(SysClkxC);
        -- end loop;  -- i

        -- TXAxi4S2MLinkxD.ReadyxS <= '0';

        -- for i in 0 to 3 loop
        --     wait until rising_edge(SysClkxC);
        -- end loop;  -- i

        -- TXAxi4S2MLinkxD.ReadyxS <= '1';

        wait until (ScalpPacketValidEndxS = '1');

        -- for i in 0 to 15 loop
        --     wait until rising_edge(SysClkxC);
        -- end loop;  -- i

        -- SchedulerAckxD(0) <= '1';

        -- wait until (RXAxi4S2MLinkxD.ReadyxS = '1');

        -- for i in 0 to 0 loop
        --     wait until rising_edge(SysClkxC);
        -- end loop;  -- i

        EndSimxS <= true;

    end process ScalpTXSideGenxP;

end architecture testbench;
