----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Quentin Berthet <quentin.berthet@hesge.ch
--
-- Module Name: scalp_hl2 - arch
-- Target Device: hepia-cores.ch:scalp_node:part0:0.1 xc7z015clg485-2
-- Tool version: 2019.2
-- Description: SCALP - HEPIALight2 interface IP
--              Work in progress, based on a DMX-512 interface
--
-- Last update: 2020/12/21 16:29:21
--
---------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library xil_defaultlib;
use xil_defaultlib.scalp_hl2_pkg.all;

entity scalp_hl2_v1_0 is
    generic (
        -- Users to add parameters here

        G_PORT_COUNT : integer := 1;
        G_CLK_DIV    : integer := 200;

        -- User parameters ends
        -- Do not modify the parameters beyond this line

        -- Parameters of Axi Slave Bus Interface S00_AXI
        C_S00_AXI_DATA_WIDTH : integer := 32;
        C_S00_AXI_ADDR_WIDTH : integer := 4;

        -- Parameters of Axi Slave Bus Interface S01_AXI
        C_S01_AXI_ID_WIDTH     : integer := 1;
        C_S01_AXI_DATA_WIDTH   : integer := 32;
        C_S01_AXI_ADDR_WIDTH   : integer := 19;
        C_S01_AXI_AWUSER_WIDTH : integer := 0;
        C_S01_AXI_ARUSER_WIDTH : integer := 0;
        C_S01_AXI_WUSER_WIDTH  : integer := 0;
        C_S01_AXI_RUSER_WIDTH  : integer := 0;
        C_S01_AXI_BUSER_WIDTH  : integer := 0
    );
    port (
        -- Users to add ports here

        HL2UartxSO : out std_logic_vector(G_PORT_COUNT - 1 downto 0);

        -- User ports ends
        -- Do not modify the ports beyond this line

        AXI_ACLK    : in std_logic;
        AXI_ARESETN : in std_logic;

        -- Ports of Axi Slave Bus Interface S00_AXI
        S00_AXI_AWADDR  : in std_logic_vector(C_S00_AXI_ADDR_WIDTH - 1 downto 0);
        S00_AXI_AWPROT  : in std_logic_vector(2 downto 0);
        S00_AXI_AWVALID : in std_logic;
        S00_AXI_AWREADY : out std_logic;
        S00_AXI_WDATA   : in std_logic_vector(C_S00_AXI_DATA_WIDTH - 1 downto 0);
        S00_AXI_WSTRB   : in std_logic_vector((C_S00_AXI_DATA_WIDTH/8) - 1 downto 0);
        S00_AXI_WVALID  : in std_logic;
        S00_AXI_WREADY  : out std_logic;
        S00_AXI_BRESP   : out std_logic_vector(1 downto 0);
        S00_AXI_BVALID  : out std_logic;
        S00_AXI_BREADY  : in std_logic;
        S00_AXI_ARADDR  : in std_logic_vector(C_S00_AXI_ADDR_WIDTH - 1 downto 0);
        S00_AXI_ARPROT  : in std_logic_vector(2 downto 0);
        S00_AXI_ARVALID : in std_logic;
        S00_AXI_ARREADY : out std_logic;
        S00_AXI_RDATA   : out std_logic_vector(C_S00_AXI_DATA_WIDTH - 1 downto 0);
        S00_AXI_RRESP   : out std_logic_vector(1 downto 0);
        S00_AXI_RVALID  : out std_logic;
        S00_AXI_RREADY  : in std_logic;

        -- Ports of Axi Slave Bus Interface S01_AXI
        S01_AXI_AWID     : in std_logic_vector(C_S01_AXI_ID_WIDTH - 1 downto 0);
        S01_AXI_AWADDR   : in std_logic_vector(C_S01_AXI_ADDR_WIDTH - 1 downto 0);
        S01_AXI_AWLEN    : in std_logic_vector(7 downto 0);
        S01_AXI_AWSIZE   : in std_logic_vector(2 downto 0);
        S01_AXI_AWBURST  : in std_logic_vector(1 downto 0);
        S01_AXI_AWLOCK   : in std_logic;
        S01_AXI_AWCACHE  : in std_logic_vector(3 downto 0);
        S01_AXI_AWPROT   : in std_logic_vector(2 downto 0);
        S01_AXI_AWQOS    : in std_logic_vector(3 downto 0);
        S01_AXI_AWREGION : in std_logic_vector(3 downto 0);
        --**s01_axi_awuser    : in  std_logic_vector(C_S01_AXI_AWUSER_WIDTH-1 downto 0);
        S01_AXI_AWVALID : in std_logic;
        S01_AXI_AWREADY : out std_logic;
        S01_AXI_WDATA   : in std_logic_vector(C_S01_AXI_DATA_WIDTH - 1 downto 0);
        S01_AXI_WSTRB   : in std_logic_vector((C_S01_AXI_DATA_WIDTH/8) - 1 downto 0);
        S01_AXI_WLAST   : in std_logic;
        --**s01_axi_wuser     : in  std_logic_vector(C_S01_AXI_WUSER_WIDTH-1 downto 0);
        S01_AXI_WVALID : in std_logic;
        S01_AXI_WREADY : out std_logic;
        S01_AXI_BID    : out std_logic_vector(C_S01_AXI_ID_WIDTH - 1 downto 0);
        S01_AXI_BRESP  : out std_logic_vector(1 downto 0);
        --**s01_axi_buser     : out std_logic_vector(C_S01_AXI_BUSER_WIDTH-1 downto 0);
        S01_AXI_BVALID   : out std_logic;
        S01_AXI_BREADY   : in std_logic;
        S01_AXI_ARID     : in std_logic_vector(C_S01_AXI_ID_WIDTH - 1 downto 0);
        S01_AXI_ARADDR   : in std_logic_vector(C_S01_AXI_ADDR_WIDTH - 1 downto 0);
        S01_AXI_ARLEN    : in std_logic_vector(7 downto 0);
        S01_AXI_ARSIZE   : in std_logic_vector(2 downto 0);
        S01_AXI_ARBURST  : in std_logic_vector(1 downto 0);
        S01_AXI_ARLOCK   : in std_logic;
        S01_AXI_ARCACHE  : in std_logic_vector(3 downto 0);
        S01_AXI_ARPROT   : in std_logic_vector(2 downto 0);
        S01_AXI_ARQOS    : in std_logic_vector(3 downto 0);
        S01_AXI_ARREGION : in std_logic_vector(3 downto 0);
        --**s01_axi_aruser    : in  std_logic_vector(C_S01_AXI_ARUSER_WIDTH-1 downto 0);
        S01_AXI_ARVALID : in std_logic;
        S01_AXI_ARREADY : out std_logic;
        S01_AXI_RID     : out std_logic_vector(C_S01_AXI_ID_WIDTH - 1 downto 0);
        S01_AXI_RDATA   : out std_logic_vector(C_S01_AXI_DATA_WIDTH - 1 downto 0);
        S01_AXI_RRESP   : out std_logic_vector(1 downto 0);
        S01_AXI_RLAST   : out std_logic;
        --**s01_axi_ruser     : out std_logic_vector(C_S01_AXI_RUSER_WIDTH-1 downto 0);
        S01_AXI_RVALID : out std_logic;
        S01_AXI_RREADY : in std_logic
    );
end scalp_hl2_v1_0;

architecture arch of scalp_hl2_v1_0 is

    -- component declaration
    component scalp_hl2_S00_AXI is
        generic (
            G_PORT_COUNT       : integer := 1;
            C_S_AXI_DATA_WIDTH : integer := 32;
            C_S_AXI_ADDR_WIDTH : integer := 4
        );
        port (
            ir_mab_clk    : out std_logic_vector(C_REG_MAB_CLK_SIZE - 1 downto 0);
            ir_break_clk  : out std_logic_vector(C_REG_BREAK_CLK_SIZE - 1 downto 0);
            ir_bit_clk    : out std_logic_vector(C_REG_BIT_CLK_SIZE - 1 downto 0);
            ir_chan_count : out std_logic_vector(C_REG_CHAN_COUNT_SIZE - 1 downto 0);
            ir_global_en  : out std_logic_vector(C_REG_GLOBAL_EN_SIZE - 1 downto 0);
            ir_sof_value  : out std_logic_vector((C_REG_SOF_VALUE_SIZE * G_PORT_COUNT) - 1 downto 0);
            ir_idl_value  : out std_logic_vector((C_REG_IDL_SIZE * G_PORT_COUNT) - 1 downto 0);
            ir_chan_en    : out std_logic_vector((C_REG_EN_SIZE * G_PORT_COUNT) - 1 downto 0);

            S_AXI_ACLK    : in std_logic;
            S_AXI_ARESETN : in std_logic;
            S_AXI_AWADDR  : in std_logic_vector(C_S_AXI_ADDR_WIDTH - 1 downto 0);
            S_AXI_AWPROT  : in std_logic_vector(2 downto 0);
            S_AXI_AWVALID : in std_logic;
            S_AXI_AWREADY : out std_logic;
            S_AXI_WDATA   : in std_logic_vector(C_S_AXI_DATA_WIDTH - 1 downto 0);
            S_AXI_WSTRB   : in std_logic_vector((C_S_AXI_DATA_WIDTH/8) - 1 downto 0);
            S_AXI_WVALID  : in std_logic;
            S_AXI_WREADY  : out std_logic;
            S_AXI_BRESP   : out std_logic_vector(1 downto 0);
            S_AXI_BVALID  : out std_logic;
            S_AXI_BREADY  : in std_logic;
            S_AXI_ARADDR  : in std_logic_vector(C_S_AXI_ADDR_WIDTH - 1 downto 0);
            S_AXI_ARPROT  : in std_logic_vector(2 downto 0);
            S_AXI_ARVALID : in std_logic;
            S_AXI_ARREADY : out std_logic;
            S_AXI_RDATA   : out std_logic_vector(C_S_AXI_DATA_WIDTH - 1 downto 0);
            S_AXI_RRESP   : out std_logic_vector(1 downto 0);
            S_AXI_RVALID  : out std_logic;
            S_AXI_RREADY  : in std_logic
        );
    end component scalp_hl2_S00_AXI;

    component scalp_hl2_S01_AXI is
        generic (
            G_PORT_COUNT         : integer := 1;
            C_S_AXI_ID_WIDTH     : integer := 1;
            C_S_AXI_DATA_WIDTH   : integer := 32;
            C_S_AXI_ADDR_WIDTH   : integer := 6;
            C_S_AXI_AWUSER_WIDTH : integer := 0;
            C_S_AXI_ARUSER_WIDTH : integer := 0;
            C_S_AXI_WUSER_WIDTH  : integer := 0;
            C_S_AXI_RUSER_WIDTH  : integer := 0;
            C_S_AXI_BUSER_WIDTH  : integer := 0
        );
        port (

            i_bram_rdata : in std_logic_vector(31 downto 0);
            o_bram_addr  : out std_logic_vector(16 downto 0);
            o_bram_wdata : out std_logic_vector(31 downto 0);
            o_bram_en    : out std_logic;
            o_bram_we    : out std_logic_vector(3 downto 0);

            S_AXI_ACLK     : in std_logic;
            S_AXI_ARESETN  : in std_logic;
            S_AXI_AWID     : in std_logic_vector(C_S_AXI_ID_WIDTH - 1 downto 0);
            S_AXI_AWADDR   : in std_logic_vector(C_S_AXI_ADDR_WIDTH - 1 downto 0);
            S_AXI_AWLEN    : in std_logic_vector(7 downto 0);
            S_AXI_AWSIZE   : in std_logic_vector(2 downto 0);
            S_AXI_AWBURST  : in std_logic_vector(1 downto 0);
            S_AXI_AWLOCK   : in std_logic;
            S_AXI_AWCACHE  : in std_logic_vector(3 downto 0);
            S_AXI_AWPROT   : in std_logic_vector(2 downto 0);
            S_AXI_AWQOS    : in std_logic_vector(3 downto 0);
            S_AXI_AWREGION : in std_logic_vector(3 downto 0);
            --**S_AXI_AWUSER   : in  std_logic_vector(C_S_AXI_AWUSER_WIDTH-1 downto 0);
            S_AXI_AWVALID : in std_logic;
            S_AXI_AWREADY : out std_logic;
            S_AXI_WDATA   : in std_logic_vector(C_S_AXI_DATA_WIDTH - 1 downto 0);
            S_AXI_WSTRB   : in std_logic_vector((C_S_AXI_DATA_WIDTH/8) - 1 downto 0);
            S_AXI_WLAST   : in std_logic;
            --**S_AXI_WUSER    : in  std_logic_vector(C_S_AXI_WUSER_WIDTH-1 downto 0);
            S_AXI_WVALID : in std_logic;
            S_AXI_WREADY : out std_logic;
            S_AXI_BID    : out std_logic_vector(C_S_AXI_ID_WIDTH - 1 downto 0);
            S_AXI_BRESP  : out std_logic_vector(1 downto 0);
            --**S_AXI_BUSER    : out std_logic_vector(C_S_AXI_BUSER_WIDTH-1 downto 0);
            S_AXI_BVALID   : out std_logic;
            S_AXI_BREADY   : in std_logic;
            S_AXI_ARID     : in std_logic_vector(C_S_AXI_ID_WIDTH - 1 downto 0);
            S_AXI_ARADDR   : in std_logic_vector(C_S_AXI_ADDR_WIDTH - 1 downto 0);
            S_AXI_ARLEN    : in std_logic_vector(7 downto 0);
            S_AXI_ARSIZE   : in std_logic_vector(2 downto 0);
            S_AXI_ARBURST  : in std_logic_vector(1 downto 0);
            S_AXI_ARLOCK   : in std_logic;
            S_AXI_ARCACHE  : in std_logic_vector(3 downto 0);
            S_AXI_ARPROT   : in std_logic_vector(2 downto 0);
            S_AXI_ARQOS    : in std_logic_vector(3 downto 0);
            S_AXI_ARREGION : in std_logic_vector(3 downto 0);
            --**S_AXI_ARUSER   : in  std_logic_vector(C_S_AXI_ARUSER_WIDTH-1 downto 0);
            S_AXI_ARVALID : in std_logic;
            S_AXI_ARREADY : out std_logic;
            S_AXI_RID     : out std_logic_vector(C_S_AXI_ID_WIDTH - 1 downto 0);
            S_AXI_RDATA   : out std_logic_vector(C_S_AXI_DATA_WIDTH - 1 downto 0);
            S_AXI_RRESP   : out std_logic_vector(1 downto 0);
            S_AXI_RLAST   : out std_logic;
            --**S_AXI_RUSER    : out std_logic_vector(C_S_AXI_RUSER_WIDTH-1 downto 0);
            S_AXI_RVALID : out std_logic;
            S_AXI_RREADY : in std_logic
        );
    end component scalp_hl2_S01_AXI;
    component scalp_hl2_ctrl is
        generic (
            G_PORT_COUNT : integer
        );
        port (
            i_clk  : in std_logic;
            i_nrst : in std_logic;

            -- Config registers
            ir_mab_clk    : in std_logic_vector(C_REG_MAB_CLK_SIZE - 1 downto 0);
            ir_break_clk  : in std_logic_vector(C_REG_BREAK_CLK_SIZE - 1 downto 0);
            ir_bit_clk    : in std_logic_vector(C_REG_BIT_CLK_SIZE - 1 downto 0);
            ir_chan_count : in std_logic_vector(C_REG_CHAN_COUNT_SIZE - 1 downto 0);
            ir_global_en  : in std_logic_vector(C_REG_GLOBAL_EN_SIZE - 1 downto 0);
            ir_sof_value  : in std_logic_vector((C_REG_SOF_VALUE_SIZE * G_PORT_COUNT) - 1 downto 0);
            ir_idl_value  : in std_logic_vector((C_REG_IDL_SIZE * G_PORT_COUNT) - 1 downto 0);
            ir_chan_en    : in std_logic_vector((C_REG_EN_SIZE * G_PORT_COUNT) - 1 downto 0);

            -- Data bus
            i_data : in std_logic_vector((8 * G_PORT_COUNT) - 1 downto 0);
            o_addr : out std_logic_vector(C_REG_CHAN_COUNT_SIZE - 1 downto 0);
            o_rden : out std_logic;

            -- Uarts vector
            o_uart : out std_logic_vector(G_PORT_COUNT - 1 downto 0)
        );
    end component scalp_hl2_ctrl;

    component scalp_hl2_bram is
        generic (
            G_PORT_COUNT : integer
        );
        port (
            i_clk  : in std_logic;
            i_nrst : in std_logic;

            -- AXI Ports Data bus
            o_axi_data : out std_logic_vector(31 downto 0);
            i_axi_addr : in std_logic_vector(16 downto 0);
            i_axi_data : in std_logic_vector(31 downto 0);
            i_axi_en   : in std_logic;
            i_axi_we   : in std_logic_vector(3 downto 0);

            -- DMX Ports Data bus
            o_dmx_data : out std_logic_vector((8 * G_PORT_COUNT) - 1 downto 0);
            i_dmx_addr : in std_logic_vector(C_REG_CHAN_COUNT_SIZE - 1 downto 0);
            i_dmx_rden : in std_logic
        );
    end component;

    -- AXI4-lite -> DMX ctrl interface (control registers)
    signal s_mab_clk    : std_logic_vector(C_REG_MAB_CLK_SIZE - 1 downto 0);
    signal s_break_clk  : std_logic_vector(C_REG_BREAK_CLK_SIZE - 1 downto 0);
    signal s_bit_clk    : std_logic_vector(C_REG_BIT_CLK_SIZE - 1 downto 0);
    signal s_chan_count : std_logic_vector(C_REG_CHAN_COUNT_SIZE - 1 downto 0);
    signal s_global_en  : std_logic_vector(C_REG_GLOBAL_EN_SIZE - 1 downto 0);
    signal s_sof_value  : std_logic_vector((C_REG_SOF_VALUE_SIZE * G_PORT_COUNT) - 1 downto 0);
    signal s_idl_value  : std_logic_vector((C_REG_IDL_SIZE * G_PORT_COUNT) - 1 downto 0);
    signal s_chan_en    : std_logic_vector((C_REG_EN_SIZE * G_PORT_COUNT) - 1 downto 0);

    -- AXI4-full <-> BRAM
    signal s_axi_bram_rdata : std_logic_vector(31 downto 0);
    signal s_axi_bram_addr  : std_logic_vector(16 downto 0);
    signal s_axi_bram_wdata : std_logic_vector(31 downto 0);
    signal s_axi_bram_en    : std_logic;
    signal s_axi_bram_we    : std_logic_vector(3 downto 0);

    -- BRAM -> DMX ctrl interface
    signal s_dmx_data : std_logic_vector((8 * G_PORT_COUNT) - 1 downto 0);
    signal s_dmx_addr : std_logic_vector(C_REG_CHAN_COUNT_SIZE - 1 downto 0);
    signal s_dmx_rden : std_logic;

begin

    -- Instantiation of Axi Bus Interface S00_AXI
    scalp_hl2_S00_AXI_inst : scalp_hl2_S00_AXI
    generic map(
        G_PORT_COUNT       => G_PORT_COUNT,
        C_S_AXI_DATA_WIDTH => C_S00_AXI_DATA_WIDTH,
        C_S_AXI_ADDR_WIDTH => C_S00_AXI_ADDR_WIDTH
    )
    port map(
        -- Config registers
        ir_mab_clk    => s_mab_clk,
        ir_break_clk  => s_break_clk,
        ir_bit_clk    => s_bit_clk,
        ir_chan_count => s_chan_count,
        ir_global_en  => s_global_en,
        ir_sof_value  => s_sof_value,
        ir_idl_value  => s_idl_value,
        ir_chan_en    => s_chan_en,

        S_AXI_ACLK    => AXI_ACLK,
        S_AXI_ARESETN => AXI_ARESETN,
        S_AXI_AWADDR  => S00_AXI_AWADDR,
        S_AXI_AWPROT  => S00_AXI_AWPROT,
        S_AXI_AWVALID => S00_AXI_AWVALID,
        S_AXI_AWREADY => S00_AXI_AWREADY,
        S_AXI_WDATA   => S00_AXI_WDATA,
        S_AXI_WSTRB   => S00_AXI_WSTRB,
        S_AXI_WVALID  => S00_AXI_WVALID,
        S_AXI_WREADY  => S00_AXI_WREADY,
        S_AXI_BRESP   => S00_AXI_BRESP,
        S_AXI_BVALID  => S00_AXI_BVALID,
        S_AXI_BREADY  => S00_AXI_BREADY,
        S_AXI_ARADDR  => S00_AXI_ARADDR,
        S_AXI_ARPROT  => S00_AXI_ARPROT,
        S_AXI_ARVALID => S00_AXI_ARVALID,
        S_AXI_ARREADY => S00_AXI_ARREADY,
        S_AXI_RDATA   => S00_AXI_RDATA,
        S_AXI_RRESP   => S00_AXI_RRESP,
        S_AXI_RVALID  => S00_AXI_RVALID,
        S_AXI_RREADY  => S00_AXI_RREADY
    );

    -- Instantiation of Axi Bus Interface S01_AXI
    scalp_hl2_S01_AXI_inst : scalp_hl2_S01_AXI
    generic map(
        G_PORT_COUNT         => G_PORT_COUNT,
        C_S_AXI_ID_WIDTH     => C_S01_AXI_ID_WIDTH,
        C_S_AXI_DATA_WIDTH   => C_S01_AXI_DATA_WIDTH,
        C_S_AXI_ADDR_WIDTH   => C_S01_AXI_ADDR_WIDTH,
        C_S_AXI_AWUSER_WIDTH => C_S01_AXI_AWUSER_WIDTH,
        C_S_AXI_ARUSER_WIDTH => C_S01_AXI_ARUSER_WIDTH,
        C_S_AXI_WUSER_WIDTH  => C_S01_AXI_WUSER_WIDTH,
        C_S_AXI_RUSER_WIDTH  => C_S01_AXI_RUSER_WIDTH,
        C_S_AXI_BUSER_WIDTH  => C_S01_AXI_BUSER_WIDTH
    )
    port map(

        i_bram_rdata => s_axi_bram_rdata,
        o_bram_addr  => s_axi_bram_addr,
        o_bram_wdata => s_axi_bram_wdata,
        o_bram_en    => s_axi_bram_en,
        o_bram_we    => s_axi_bram_we,

        S_AXI_ACLK     => AXI_ACLK,
        S_AXI_ARESETN  => AXI_ARESETN,
        S_AXI_AWID     => S01_AXI_AWID,
        S_AXI_AWADDR   => S01_AXI_AWADDR,
        S_AXI_AWLEN    => S01_AXI_AWLEN,
        S_AXI_AWSIZE   => S01_AXI_AWSIZE,
        S_AXI_AWBURST  => S01_AXI_AWBURST,
        S_AXI_AWLOCK   => S01_AXI_AWLOCK,
        S_AXI_AWCACHE  => S01_AXI_AWCACHE,
        S_AXI_AWPROT   => S01_AXI_AWPROT,
        S_AXI_AWQOS    => S01_AXI_AWQOS,
        S_AXI_AWREGION => S01_AXI_AWREGION,
        --**S_AXI_AWUSER   => S01_AXI_AWUSER,
        S_AXI_AWVALID => S01_AXI_AWVALID,
        S_AXI_AWREADY => S01_AXI_AWREADY,
        S_AXI_WDATA   => S01_AXI_WDATA,
        S_AXI_WSTRB   => S01_AXI_WSTRB,
        S_AXI_WLAST   => S01_AXI_WLAST,
        --**S_AXI_WUSER    => S01_AXI_WUSER,
        S_AXI_WVALID => S01_AXI_WVALID,
        S_AXI_WREADY => S01_AXI_WREADY,
        S_AXI_BID    => S01_AXI_BID,
        S_AXI_BRESP  => S01_AXI_BRESP,
        --**S_AXI_BUSER    => S01_AXI_BUSER,
        S_AXI_BVALID   => S01_AXI_BVALID,
        S_AXI_BREADY   => S01_AXI_BREADY,
        S_AXI_ARID     => S01_AXI_ARID,
        S_AXI_ARADDR   => S01_AXI_ARADDR,
        S_AXI_ARLEN    => S01_AXI_ARLEN,
        S_AXI_ARSIZE   => S01_AXI_ARSIZE,
        S_AXI_ARBURST  => S01_AXI_ARBURST,
        S_AXI_ARLOCK   => S01_AXI_ARLOCK,
        S_AXI_ARCACHE  => S01_AXI_ARCACHE,
        S_AXI_ARPROT   => S01_AXI_ARPROT,
        S_AXI_ARQOS    => S01_AXI_ARQOS,
        S_AXI_ARREGION => S01_AXI_ARREGION,
        --**S_AXI_ARUSER   => S01_AXI_ARUSER,
        S_AXI_ARVALID => S01_AXI_ARVALID,
        S_AXI_ARREADY => S01_AXI_ARREADY,
        S_AXI_RID     => S01_AXI_RID,
        S_AXI_RDATA   => S01_AXI_RDATA,
        S_AXI_RRESP   => S01_AXI_RRESP,
        S_AXI_RLAST   => S01_AXI_RLAST,
        --**S_AXI_RUSER    => S01_AXI_RUSER,
        S_AXI_RVALID => S01_AXI_RVALID,
        S_AXI_RREADY => S01_AXI_RREADY
    );

    -- Add user logic here

    -- Instantiation
    scalp_hl2_ctrl_inst : scalp_hl2_ctrl
    generic map(
        G_PORT_COUNT => G_PORT_COUNT
    )
    port map(
        i_clk  => AXI_ACLK,
        i_nrst => AXI_ARESETN,

        -- Config registers
        ir_mab_clk    => s_mab_clk,
        ir_break_clk  => s_break_clk,
        ir_bit_clk    => s_bit_clk,
        ir_chan_count => s_chan_count,
        ir_global_en  => s_global_en,
        ir_sof_value  => s_sof_value,
        ir_idl_value  => s_idl_value,
        ir_chan_en    => s_chan_en,

        -- Data bus
        i_data => s_dmx_data,
        o_addr => s_dmx_addr,
        o_rden => s_dmx_rden,

        -- Dmx
        o_uart => HL2UartxSO
    );

    -- BRAM instance
    scalp_hl2_bram_i : scalp_hl2_bram
    generic map(
        G_PORT_COUNT => G_PORT_COUNT
    )
    port map(
        i_clk  => AXI_ACLK,
        i_nrst => AXI_ARESETN,

        -- AXI Ports Data bus
        o_axi_data => s_axi_bram_rdata,
        i_axi_addr => s_axi_bram_addr,
        i_axi_data => s_axi_bram_wdata,
        i_axi_en   => s_axi_bram_en,
        i_axi_we   => s_axi_bram_we,

        -- DMX Ports Data bus
        o_dmx_data => s_dmx_data,
        i_dmx_addr => s_dmx_addr,
        i_dmx_rden => s_dmx_rden
    );

    -- User logic ends

end arch;