----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Quentin Berthet <quentin.berthet@hesge.ch
--
-- Module Name: scalp_hl2_pkg
-- Target Device: hepia-cores.ch:scalp_node:part0:0.1 xc7z015clg485-2
-- Tool version: 2019.2
-- Description: SCALP - HEPIALight2 configuration package
--
-- Last update: 2020/12/21 17:32:11
--
---------------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.all;
use IEEE.NUMERIC_STD.all;

package scalp_hl2_pkg is

    -- Info register ----------------------------------------------------------

    -- PORT_COUNT
    constant C_REG_PORT_COUNT_SIZE : integer := 8;
    constant C_REG_PORT_COUNT_POS  : integer := 8;
    --constant C_REG_PORT_COUNT_RESET_VAL  : integer := 0; GENERIC

    -- IP_REV_MAJ
    constant C_REG_IP_REV_MAJ_SIZE      : integer := 4;
    constant C_REG_IP_REV_MAJ_POS       : integer := 4;
    constant C_REG_IP_REV_MAJ_RESET_VAL : integer := 1;

    -- IP_REV_MIN
    constant C_REG_IP_REV_MIN_SIZE      : integer := 4;
    constant C_REG_IP_REV_MIN_POS       : integer := 0;
    constant C_REG_IP_REV_MIN_RESET_VAL : integer := 0;

    -- Global clock config register -------------------------------------------
    -- BIT_CLK
    --  Standard DMX-512 use a 250kbit bit clock
    --  With a 125MHz AXI clock must divide by 500
    --  With a 50MHz AXI clock must divide by 200
    constant C_REG_BIT_CLK_SIZE      : integer := 16;
    constant C_REG_BIT_CLK_POS       : integer := 0;
    constant C_REG_BIT_CLK_RESET_VAL : integer := 500;

    -- Global break config register -------------------------------------------

    -- MAB_CLK
    constant C_REG_MAB_CLK_SIZE      : integer := 16;
    constant C_REG_MAB_CLK_POS       : integer := 16;
    constant C_REG_MAB_CLK_RESET_VAL : integer := 3 * C_REG_BIT_CLK_RESET_VAL;

    -- BREAK_CLK
    constant C_REG_BREAK_CLK_SIZE      : integer := 16;
    constant C_REG_BREAK_CLK_POS       : integer := 0;
    constant C_REG_BREAK_CLK_RESET_VAL : integer := 23 * C_REG_BIT_CLK_RESET_VAL;

    -- Global control register ------------------------------------------------

    -- CHAN_COUNT
    constant C_REG_CHAN_COUNT_SIZE      : integer := 12;
    constant C_REG_CHAN_COUNT_POS       : integer := 16;
    constant C_REG_CHAN_COUNT_RESET_VAL : integer := 512;

    -- GLOBAL_EN
    constant C_REG_GLOBAL_EN_SIZE      : integer := 1;
    constant C_REG_GLOBAL_EN_POS       : integer := 0;
    constant C_REG_GLOBAL_EN_RESET_VAL : integer := 1;

    -- Port N control register ------------------------------------------------

    -- SOF_VALUE
    constant C_REG_SOF_VALUE_SIZE      : integer := 8;
    constant C_REG_SOF_VALUE_POS       : integer := 8;
    constant C_REG_SOF_VALUE_RESET_VAL : integer := 0;

    -- IDL
    constant C_REG_IDL_SIZE      : integer := 1;
    constant C_REG_IDL_POS       : integer := 1;
    constant C_REG_IDL_RESET_VAL : integer := 0;

    -- EN
    constant C_REG_EN_SIZE      : integer := 1;
    constant C_REG_EN_POS       : integer := 0;
    constant C_REG_EN_RESET_VAL : integer := 1;

end scalp_hl2_pkg;

package body scalp_hl2_pkg is

end scalp_hl2_pkg;